@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2017 Zabbix SIA
+** Copyright (C) 2001-2018 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@ class CCorrelation extends CApiService {
 			'selectFilter'		=> null,
 			'selectOperations'	=> null,
 			'correlationids'	=> null,
-			'editable'			=> null,
+			'editable'			=> false,
 			'sortfield'			=> '',
 			'sortorder'			=> ''
 		]);
@@ -54,28 +54,28 @@ class CCorrelation extends CApiService {
 	public function get($options = []) {
 		$options = zbx_array_merge($this->getOptions, $options);
 
-		if ($options['editable'] !== null && self::$userData['type'] != USER_TYPE_SUPER_ADMIN) {
-			return ($options['countOutput'] !== null && $options['groupCount'] === null) ? 0 : [];
+		if ($options['editable'] && self::$userData['type'] != USER_TYPE_SUPER_ADMIN) {
+			return ($options['countOutput'] && !$options['groupCount']) ? 0 : [];
 		}
 
 		$res = DBselect($this->createSelectQuery($this->tableName(), $options), $options['limit']);
 
 		$result = [];
 		while ($row = DBfetch($res)) {
-			if ($options['countOutput'] === null) {
-				$result[$row[$this->pk()]] = $row;
-			}
-			else {
-				if ($options['groupCount'] === null) {
-					$result = $row['rowscount'];
-				}
-				else {
+			if ($options['countOutput']) {
+				if ($options['groupCount']) {
 					$result[] = $row;
 				}
+				else {
+					$result = $row['rowscount'];
+				}
+			}
+			else {
+				$result[$row[$this->pk()]] = $row;
 			}
 		}
 
-		if ($options['countOutput'] !== null) {
+		if ($options['countOutput']) {
 			return $result;
 		}
 
@@ -108,7 +108,7 @@ class CCorrelation extends CApiService {
 		}
 
 		// removing keys (hash -> array)
-		if ($options['preservekeys'] === null) {
+		if (!$options['preservekeys']) {
 			$result = zbx_cleanHashes($result);
 		}
 
@@ -471,24 +471,22 @@ class CCorrelation extends CApiService {
 	 */
 	public function delete(array $correlationids) {
 		if (self::$userData['type'] != USER_TYPE_SUPER_ADMIN) {
-			self::exception(ZBX_API_ERROR_PERMISSIONS, _('Only super admins can delete correlations.'));
+			self::exception(ZBX_API_ERROR_PERMISSIONS, _('You do not have permission to perform this operation.'));
 		}
 
-		if (!$correlationids) {
-			self::exception(ZBX_API_ERROR_PARAMETERS, _('Empty input parameter.'));
+		$api_input_rules = ['type' => API_IDS, 'flags' => API_NOT_EMPTY, 'uniq' => true];
+		if (!CApiInputValidator::validate($api_input_rules, $correlationids, '/', $error)) {
+			self::exception(ZBX_API_ERROR_PARAMETERS, $error);
 		}
 
 		$db_correlations = $this->get([
-			'output' => ['correlationid'],
+			'output' => ['correlationid', 'name'],
 			'correlationids' => $correlationids,
 			'preservekeys' => true
 		]);
 
 		foreach ($correlationids as $correlationid) {
-			if (!is_int($correlationid) && !is_string($correlationid)) {
-				self::exception(ZBX_API_ERROR_PARAMETERS, _('Incorrect arguments passed to function.'));
-			}
-			elseif (!array_key_exists($correlationid, $db_correlations)) {
+			if (!array_key_exists($correlationid, $db_correlations)) {
 				self::exception(ZBX_API_ERROR_PERMISSIONS,
 					_('No permissions to referred object or it does not exist!')
 				);
@@ -497,6 +495,8 @@ class CCorrelation extends CApiService {
 
 		DB::delete('correlation', ['correlationid' => $correlationids]);
 
+		$this->addAuditBulk(AUDIT_ACTION_DELETE, AUDIT_RESOURCE_CORRELATION, $db_correlations);
+
 		return ['correlationids' => $correlationids];
 	}
 
@@ -662,10 +662,17 @@ class CCorrelation extends CApiService {
 		}
 
 		// Validate collected group IDs if at least one of correlation conditions was "New event host group".
-		if ($groupids && !API::HostGroup()->isReadable(array_keys($groupids))) {
-			self::exception(ZBX_API_ERROR_PERMISSIONS,
-				_('No permissions to referred object or it does not exist!')
-			);
+		if ($groupids) {
+			$groups_count = API::HostGroup()->get([
+				'countOutput' => true,
+				'groupids' => array_keys($groupids)
+			]);
+
+			if ($groups_count != count($groupids)) {
+				self::exception(ZBX_API_ERROR_PERMISSIONS,
+					_('No permissions to referred object or it does not exist!')
+				);
+			}
 		}
 	}
 
@@ -909,10 +916,17 @@ class CCorrelation extends CApiService {
 		}
 
 		// Validate collected group IDs if at least one of correlation conditions was "New event host group".
-		if ($groupids && !API::HostGroup()->isReadable(array_keys($groupids))) {
-			self::exception(ZBX_API_ERROR_PERMISSIONS,
-				_('No permissions to referred object or it does not exist!')
-			);
+		if ($groupids) {
+			$groups_count = API::HostGroup()->get([
+				'countOutput' => true,
+				'groupids' => array_keys($groupids)
+			]);
+
+			if ($groups_count != count($groupids)) {
+				self::exception(ZBX_API_ERROR_PERMISSIONS,
+					_('No permissions to referred object or it does not exist!')
+				);
+			}
 		}
 	}
 
@@ -1187,7 +1201,7 @@ class CCorrelation extends CApiService {
 		if (!$parser->parse($correlation['filter']['formula'])) {
 			self::exception(ZBX_API_ERROR_PARAMETERS,
 				_s('Incorrect custom expression "%2$s" for correlation "%1$s": %3$s.',
-					$correlation['filter']['formula'], $correlation['name'], $parser->error
+					$correlation['name'], $correlation['filter']['formula'], $parser->error
 				)
 			);
 		}
@@ -1373,7 +1387,7 @@ class CCorrelation extends CApiService {
 	protected function applyQueryOutputOptions($table_name, $table_alias, array $options, array $sql_parts) {
 		$sql_parts = parent::applyQueryOutputOptions($table_name, $table_alias, $options, $sql_parts);
 
-		if ($options['countOutput'] === null) {
+		if (!$options['countOutput']) {
 			// Add filter fields.
 			if ($this->outputIsRequested('formula', $options['selectFilter'])
 					|| $this->outputIsRequested('eval_formula', $options['selectFilter'])
