@@ -230,7 +230,7 @@ class CLineGraphDraw extends CGraphDraw {
 				$to_resolve[] = 'trends';
 			}
 
-			// Otherwise, resolve user macro and parse the string. If successfull, convert to seconds.
+			// Otherwise, resolve user macro and parse the string. If successful, convert to seconds.
 			if ($to_resolve) {
 				$item = CMacrosResolverHelper::resolveTimeUnitMacros([$item], $to_resolve)[0];
 
@@ -445,7 +445,7 @@ class CLineGraphDraw extends CGraphDraw {
 				'SELECT DISTINCT h.host,tr.description,tr.triggerid,tr.expression,tr.priority,tr.value'.
 				' FROM triggers tr,functions f,items i,hosts h'.
 				' WHERE tr.triggerid=f.triggerid'.
-					" AND f.function IN ('last','min','avg','max')".
+					" AND f.name IN ('last','min','avg','max')".
 					' AND tr.status='.TRIGGER_STATUS_ENABLED.
 					' AND i.itemid=f.itemid'.
 					' AND h.hostid=i.hostid'.
@@ -741,7 +741,9 @@ class CLineGraphDraw extends CGraphDraw {
 				}
 			}
 			else {
-				$this->zero[$side] = $this->sizeY + $this->shiftY - (int) abs($this->m_minY[$side] / $this->unit2px[$side]);
+				$this->zero[$side] = $this->sizeY + $this->shiftY - abs(bcdiv($this->m_minY[$side],
+					$this->unit2px[$side]
+				));
 				$this->oxy[$side] = 0;
 			}
 		}
@@ -2515,8 +2517,6 @@ class CLineGraphDraw extends CGraphDraw {
 		$this->selectTriggers();
 		$this->calcDimentions();
 
-		$this->initColors();
-
 		if (function_exists('imagecolorexactalpha') && function_exists('imagecreatetruecolor')
 				&& @imagecreatetruecolor(1, 1)
 		) {
@@ -2526,6 +2526,8 @@ class CLineGraphDraw extends CGraphDraw {
 			$this->im = imagecreate(1, 1);
 		}
 
+		$this->initColors();
+
 		imageOut($this->im);
 	}
 
