@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2017 Zabbix SIA
+** Copyright (C) 2001-2018 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -44,25 +44,16 @@ class CScreenProblem extends CScreenBase {
 	 */
 	public function __construct(array $options = []) {
 		parent::__construct($options);
-
 		$this->data = array_key_exists('data', $options) ? $options['data'] : null;
 
 		if ($this->data['filter']['show'] == TRIGGERS_OPTION_ALL) {
-			CProfile::update('web.problem.timeline.period', $this->data['filter']['period'], PROFILE_TYPE_INT);
-			CProfile::update('web.problem.timeline.stime', $this->data['filter']['stime'], PROFILE_TYPE_STR);
-
-			$time = time();
-
-			$this->data['filter']['stime'] = zbxDateToTime($this->data['filter']['stime']);
-			if ($this->data['filter']['stime'] > $time - $this->data['filter']['period']) {
-				$this->data['filter']['stime'] = $time - $this->data['filter']['period'];
-			}
+			$this->data['filter']['from'] = $this->timeline['from_ts'];
+			$this->data['filter']['to'] = $this->timeline['to_ts'];
 		}
 
 		$config = select_config();
 
 		$this->config = [
-			'event_ack_enable' => $config['event_ack_enable'],
 			'search_limit' => $config['search_limit'],
 			'severity_color_0' => $config['severity_color_0'],
 			'severity_color_1' => $config['severity_color_1'],
@@ -101,7 +92,7 @@ class CScreenProblem extends CScreenBase {
 	 */
 	private static function getDataEvents(array $options) {
 		return API::Event()->get([
-			'output' => ['eventid', 'objectid', 'clock', 'ns'],
+			'output' => ['eventid', 'objectid', 'clock', 'ns', 'name', 'severity'],
 			'source' => EVENT_SOURCE_TRIGGERS,
 			'object' => EVENT_OBJECT_TRIGGER,
 			'value' => TRIGGER_VALUE_TRUE,
@@ -133,7 +124,7 @@ class CScreenProblem extends CScreenBase {
 	 */
 	private static function getDataProblems(array $options) {
 		return API::Problem()->get([
-			'output' => ['eventid', 'objectid', 'clock', 'ns'],
+			'output' => ['eventid', 'objectid', 'clock', 'ns', 'name', 'severity'],
 			'source' => EVENT_SOURCE_TRIGGERS,
 			'object' => EVENT_OBJECT_TRIGGER,
 			'sortfield' => ['eventid'],
@@ -158,12 +149,12 @@ class CScreenProblem extends CScreenBase {
 	 * @param string $filter['inventory'][]['field']
 	 * @param string $filter['inventory'][]['value']
 	 * @param string $filter['application']           (optional)
-	 * @param string $filter['problem']               (optional)
+	 * @param string $filter['name']                  (optional)
 	 * @param int    $filter['show']                  TRIGGERS_OPTION_*
-	 * @param int    $filter['stime']                 (optional) usable together with 'period' and only for
-	 *                                                           TRIGGERS_OPTION_ALL
-	 * @param int    $filter['period']                (optional) usable together with 'stime' and only for
-	 *                                                           TRIGGERS_OPTION_ALL
+	 * @param int    $filter['from']                  (optional) usable together with 'to' and only for
+	 *                                                           TRIGGERS_OPTION_ALL, timestamp.
+	 * @param int    $filter['to']                    (optional) usable together with 'from' and only for
+	 *                                                           TRIGGERS_OPTION_ALL, timestamp.
 	 * @param int    $filter['age_state']             (optional) usable together with 'age' and only for
 	 *                                                           TRIGGERS_OPTION_(RECENT|IN)_PROBLEM
 	 * @param int    $filter['age']                   (optional) usable together with 'age_state' and only for
@@ -174,17 +165,15 @@ class CScreenProblem extends CScreenBase {
 	 * @param array  $filter['tags']                  (optional)
 	 * @param string $filter['tags'][]['tag']
 	 * @param string $filter['tags'][]['value']
-	 * @param int    $filter['maintenance']           (optional)
+	 * @param int    $filter['show_suppressed']       (optional)
 	 * @param array  $config
 	 * @param int    $config['search_limit']
-	 * @param int    $config['event_ack_enable']
-	 * @param bool   $get_comments
 	 *
 	 * @static
 	 *
 	 * @return array
 	 */
-	public static function getData(array $filter, array $config, $get_comments = false) {
+	public static function getData(array $filter, array $config) {
 		$filter_groupids = array_key_exists('groupids', $filter) && $filter['groupids'] ? $filter['groupids'] : null;
 		$filter_hostids = array_key_exists('hostids', $filter) && $filter['hostids'] ? $filter['hostids'] : null;
 		$filter_applicationids = null;
@@ -249,24 +238,6 @@ class CScreenProblem extends CScreenBase {
 			$filter_hostids = null;
 		}
 
-		if (array_key_exists('problem', $filter) && $filter['problem'] !== '') {
-			$triggerids = array_keys(API::Trigger()->get([
-				'output' => [],
-				'groupids' => $filter_groupids,
-				'hostids' => $filter_hostids,
-				'applicationids' => $filter_applicationids,
-				'search' => ['description' => $filter['problem']],
-				'preservekeys' => true
-			]));
-
-			$filter_triggerids = ($filter_triggerids !== null)
-				? array_intersect($filter_triggerids, $triggerids)
-				: $triggerids;
-			$filter_groupids = null;
-			$filter_hostids = null;
-			$filter_applicationids = null;
-		}
-
 		$data = [
 			'problems' => [],
 			'triggers' => []
@@ -282,12 +253,18 @@ class CScreenProblem extends CScreenBase {
 				'applicationids' => $filter_applicationids,
 				'objectids' => $filter_triggerids,
 				'eventid_till' => $eventid_till,
+				'suppressed' => false,
 				'limit' => $config['search_limit'] + 1
 			];
+
+			if (array_key_exists('name', $filter) && $filter['name'] !== '') {
+				$options['search']['name'] = $filter['name'];
+			}
+
 			if ($filter['show'] == TRIGGERS_OPTION_ALL) {
-				if (array_key_exists('stime', $filter) && array_key_exists('period', $filter)) {
-					$options['time_from'] = $filter['stime'];
-					$options['time_till'] = $filter['stime'] + $filter['period'];
+				if (array_key_exists('from', $filter) && array_key_exists('to', $filter)) {
+					$options['time_from'] = $filter['from'];
+					$options['time_till'] = $filter['to'];
 				}
 			}
 			else {
@@ -308,13 +285,19 @@ class CScreenProblem extends CScreenBase {
 					$options['severities'] = $filter['severities'];
 				}
 			}
-			if (array_key_exists('unacknowledged', $filter) && $filter['unacknowledged']
-					&& $config['event_ack_enable']) {
+			if (array_key_exists('unacknowledged', $filter) && $filter['unacknowledged']) {
 				$options['acknowledged'] = false;
 			}
+			if (array_key_exists('evaltype', $filter)) {
+				$options['evaltype'] = $filter['evaltype'];
+			}
 			if (array_key_exists('tags', $filter) && $filter['tags']) {
 				$options['tags'] = $filter['tags'];
 			}
+			if (array_key_exists('show_suppressed', $filter) && $filter['show_suppressed']) {
+				unset($options['suppressed']);
+				$options['selectSuppressionData'] = ['maintenanceid', 'suppress_until'];
+			}
 
 			$problems = ($filter['show'] == TRIGGERS_OPTION_ALL)
 				? self::getDataEvents($options)
@@ -326,6 +309,10 @@ class CScreenProblem extends CScreenBase {
 				$eventid_till = end($problems)['eventid'] - 1;
 				$triggerids = [];
 
+				if (array_key_exists('show_suppressed', $filter) && $filter['show_suppressed']) {
+					self::addMaintenanceNames($problems);
+				}
+
 				foreach ($problems as $problem) {
 					if (!array_key_exists($problem['objectid'], $seen_triggerids)) {
 						$triggerids[$problem['objectid']] = true;
@@ -336,9 +323,7 @@ class CScreenProblem extends CScreenBase {
 					$seen_triggerids += $triggerids;
 
 					$options = [
-						'output' => ['triggerid', 'description', 'expression', 'recovery_mode', 'recovery_expression',
-							'priority', 'url', 'flags'
-						],
+						'output' => ['priority', 'url', 'flags', 'expression', 'comments'],
 						'selectHosts' => ['hostid', 'name', 'status'],
 						'selectItems' => ['itemid', 'hostid', 'name', 'key_', 'value_type'],
 						'triggerids' => array_keys($triggerids),
@@ -346,11 +331,9 @@ class CScreenProblem extends CScreenBase {
 						'skipDependent' => true,
 						'preservekeys' => true
 					];
-					if ($get_comments) {
-						$options['output'][] = 'comments';
-					}
-					if (array_key_exists('maintenance', $filter) && $filter['maintenance'] == 0) {
-						$options['maintenance'] = false;
+
+					if (array_key_exists('details', $filter) && $filter['details'] == 1) {
+						$options['output'] = array_merge($options['output'], ['recovery_mode', 'recovery_expression']);
 					}
 
 					$data['triggers'] += API::Trigger()->get($options);
@@ -372,6 +355,47 @@ class CScreenProblem extends CScreenBase {
 		return $data;
 	}
 
+	/**
+	 * Adds maintenance names of suppressed problems.
+	 *
+	 * @param array $problems
+	 * @param array $problems[]['suppression_data']
+	 * @param int   $problems[]['suppression_data'][]['maintenanceid']
+	 *
+	 * @static
+	 */
+	public static function addMaintenanceNames(array &$problems) {
+		$maintenanceids = [];
+
+		foreach ($problems as $problem) {
+			if (array_key_exists('suppression_data', $problem) && $problem['suppression_data']) {
+				foreach ($problem['suppression_data'] as $data) {
+					$maintenanceids[] = $data['maintenanceid'];
+				}
+			}
+		}
+
+		$maintenances = $maintenanceids
+			? API::Maintenance()->get([
+				'output' => ['name'],
+				'maintenanceids' => $maintenanceids,
+				'preservekeys' => true
+			])
+			: [];
+
+		if ($maintenances) {
+			foreach ($problems as &$problem) {
+				if (array_key_exists('suppression_data', $problem) && $problem['suppression_data']) {
+					foreach ($problem['suppression_data'] as &$data) {
+						$data['maintenance_name'] = $maintenances[$data['maintenanceid']]['name'];
+					}
+					unset($data);
+				}
+			}
+			unset($problem);
+		}
+	}
+
 	/**
 	 * @param array  $data
 	 * @param array  $data['problems']
@@ -412,27 +436,17 @@ class CScreenProblem extends CScreenBase {
 				];
 				break;
 
-			case 'priority':
-				foreach ($data['problems'] as &$problem) {
-					$problem['priority'] = $data['triggers'][$problem['objectid']]['priority'];
-				}
-				unset($problem);
-
+			case 'severity':
 				$sort_fields = [
-					['field' => 'priority', 'order' => $sortorder],
+					['field' => 'severity', 'order' => $sortorder],
 					['field' => 'clock', 'order' => ZBX_SORT_DOWN],
 					['field' => 'ns', 'order' => ZBX_SORT_DOWN]
 				];
 				break;
 
-			case 'problem':
-				foreach ($data['problems'] as &$problem) {
-					$problem['description'] = $data['triggers'][$problem['objectid']]['description'];
-				}
-				unset($problem);
-
+			case 'name':
 				$sort_fields = [
-					['field' => 'description', 'order' => $sortorder],
+					['field' => 'name', 'order' => $sortorder],
 					['field' => 'objectid', 'order' => $sortorder],
 					['field' => 'clock', 'order' => ZBX_SORT_DOWN],
 					['field' => 'ns', 'order' => ZBX_SORT_DOWN]
@@ -454,26 +468,21 @@ class CScreenProblem extends CScreenBase {
 
 	/**
 	 * @param array $eventids
-	 * @param array $config
-	 * @param int   $config['event_ack_enable']
 	 *
 	 * @static
 	 *
 	 * @return array
 	 */
-	private static function getExDataEvents(array $eventids, array $config) {
-		$options = [
-			'output' => ['eventid', 'r_eventid'],
+	private static function getExDataEvents(array $eventids) {
+		$events = API::Event()->get([
+			'output' => ['eventid', 'r_eventid', 'acknowledged'],
 			'selectTags' => ['tag', 'value'],
+			'select_acknowledges' => ['userid', 'clock', 'message', 'action', 'old_severity', 'new_severity'],
 			'source' => EVENT_SOURCE_TRIGGERS,
 			'object' => EVENT_OBJECT_TRIGGER,
-			'eventids' => $eventids
-		];
-		if ($config['event_ack_enable']) {
-			$options['select_acknowledges'] = ['userid', 'clock', 'message', 'action'];
-		}
-
-		$events = API::Event()->get($options);
+			'eventids' => $eventids,
+			'preservekeys' => true
+		]);
 
 		$r_eventids = [];
 
@@ -511,27 +520,22 @@ class CScreenProblem extends CScreenBase {
 
 	/**
 	 * @param array $eventids
-	 * @param array $config
-	 * @param int   $config['event_ack_enable']
 	 *
 	 * @static
 	 *
 	 * @return array
 	 */
-	private static function getExDataProblems(array $eventids, array $config) {
-		$options = [
-			'output' => ['eventid', 'r_eventid', 'r_clock', 'correlationid', 'userid'],
+	private static function getExDataProblems(array $eventids) {
+		return API::Problem()->get([
+			'output' => ['eventid', 'r_eventid', 'r_clock', 'correlationid', 'userid', 'acknowledged'],
 			'selectTags' => ['tag', 'value'],
+			'selectAcknowledges' => ['userid', 'clock', 'message', 'action', 'old_severity', 'new_severity'],
 			'source' => EVENT_SOURCE_TRIGGERS,
 			'object' => EVENT_OBJECT_TRIGGER,
 			'eventids' => $eventids,
-			'recent' => true
-		];
-		if ($config['event_ack_enable']) {
-			$options['selectAcknowledges'] = ['userid', 'clock', 'message', 'action'];
-		}
-
-		return API::Problem()->get($options);
+			'recent' => true,
+			'preservekeys' => true
+		]);
 	}
 
 	/**
@@ -541,15 +545,13 @@ class CScreenProblem extends CScreenBase {
 	 * @param array $filter
 	 * @param int   $filter['details']
 	 * @param int   $filter['show']
-	 * @param array $config
-	 * @param int   $config['event_ack_enable']
-	 * @param bool  $get_comments
+	 * @param bool  $resolve_comments
 	 *
 	 * @static
 	 *
 	 * @return array
 	 */
-	public static function makeData(array $data, array $filter, array $config, $get_comments = false) {
+	public static function makeData(array $data, array $filter, $resolve_comments = false) {
 		// unset unused triggers
 		$triggerids = [];
 
@@ -583,7 +585,7 @@ class CScreenProblem extends CScreenBase {
 			]);
 		}
 		$data['triggers'] = CMacrosResolverHelper::resolveTriggerUrls($data['triggers']);
-		if ($get_comments) {
+		if ($resolve_comments) {
 			$data['triggers'] = CMacrosResolverHelper::resolveTriggerDescriptions($data['triggers']);
 		}
 
@@ -591,33 +593,40 @@ class CScreenProblem extends CScreenBase {
 		$eventids = array_keys($data['problems']);
 
 		$problems_data = ($filter['show'] == TRIGGERS_OPTION_ALL)
-			? self::getExDataEvents($eventids, $config)
-			: self::getExDataProblems($eventids, $config);
+			? self::getExDataEvents($eventids)
+			: self::getExDataProblems($eventids);
 
 		$correlationids = [];
 		$userids = [];
 
-		foreach ($problems_data as $problem_data) {
-			$problem = &$data['problems'][$problem_data['eventid']];
+		foreach ($data['problems'] as $eventid => &$problem) {
+			if (array_key_exists($eventid, $problems_data)) {
+				$problem_data = $problems_data[$eventid];
 
-			$problem['r_eventid'] = $problem_data['r_eventid'];
-			$problem['r_clock'] = $problem_data['r_clock'];
-			if ($config['event_ack_enable']) {
+				$problem['r_eventid'] = $problem_data['r_eventid'];
+				$problem['r_clock'] = $problem_data['r_clock'];
 				$problem['acknowledges'] = $problem_data['acknowledges'];
-			}
-			$problem['tags'] = $problem_data['tags'];
-			$problem['correlationid'] = $problem_data['correlationid'];
-			$problem['userid'] = $problem_data['userid'];
+				$problem['tags'] = $problem_data['tags'];
+				$problem['correlationid'] = $problem_data['correlationid'];
+				$problem['userid'] = $problem_data['userid'];
+				$problem['acknowledged'] = $problem_data['acknowledged'];
 
-			if ($problem['correlationid'] != 0) {
-				$correlationids[$problem['correlationid']] = true;
+				if ($problem['correlationid'] != 0) {
+					$correlationids[$problem['correlationid']] = true;
+				}
+				if ($problem['userid'] != 0) {
+					$userids[$problem['userid']] = true;
+				}
 			}
-			if ($problem['userid'] != 0) {
-				$userids[$problem['userid']] = true;
+			else {
+				unset($data['problems'][$eventid]);
 			}
-
-			unset($problem);
 		}
+		unset($problem);
+
+		// Possible performance improvement: one API call may be saved, if r_clock for problem will be used.
+		$actions = getEventsActionsIconsData($data['problems'], $data['triggers']);
+		$data['actions'] = $actions['data'];
 
 		$data['correlations'] = $correlationids
 			? API::Correlation()->get([
@@ -627,10 +636,19 @@ class CScreenProblem extends CScreenBase {
 			])
 			: [];
 
+		$userids = $userids + $actions['userids'];
 		$data['users'] = $userids
 			? API::User()->get([
 				'output' => ['alias', 'name', 'surname'],
-				'userids' => array_keys($userids),
+				'userids' => array_keys($userids + $actions['userids']),
+				'preservekeys' => true
+			])
+			: [];
+
+		$data['mediatypes'] = $actions['mediatypeids']
+			? API::Mediatype()->get([
+				'output' => ['description', 'maxattempts'],
+				'mediatypeids' => array_keys($actions['mediatypeids']),
 				'preservekeys' => true
 			])
 			: [];
@@ -698,23 +716,50 @@ class CScreenProblem extends CScreenBase {
 	public function get() {
 		$this->dataId = 'problem';
 
-		$url = (new CUrl('zabbix.php'))
-			->setArgument('action', 'problem.view')
-			->setArgument('fullscreen', $this->data['fullscreen']);
+		$url = (new CUrl('zabbix.php'))->setArgument('action', 'problem.view');
 
 		$data = self::getData($this->data['filter'], $this->config);
 		$data = self::sortData($data, $this->config, $this->data['sort'], $this->data['sortorder']);
 
 		$paging = getPagingLine($data['problems'], ZBX_SORT_UP, clone $url);
 
-		$data = self::makeData($data, $this->data['filter'], $this->config);
+		$data = self::makeData($data, $this->data['filter']);
+
+		if ($data['triggers']) {
+			$triggerids = array_keys($data['triggers']);
+
+			$db_triggers = API::Trigger()->get([
+				'output' => [],
+				'selectDependencies' => ['triggerid'],
+				'triggerids' => $triggerids,
+				'preservekeys' => true
+			]);
+
+			foreach ($data['triggers'] as $triggerid => &$trigger) {
+				$trigger['dependencies'] = array_key_exists($triggerid, $db_triggers)
+					? $db_triggers[$triggerid]['dependencies']
+					: [];
+			}
+			unset($trigger);
+
+			$rw_triggers = API::Trigger()->get([
+				'output' => [],
+				'triggerids' => $triggerids,
+				'editable' => true,
+				'preservekeys' => true
+			]);
+
+			foreach ($data['triggers'] as $triggerid => &$trigger) {
+				$trigger['editable'] = array_key_exists($triggerid, $rw_triggers);
+			}
+			unset($trigger);
+		}
 
 		if ($data['problems']) {
 			$triggers_hosts = getTriggersHostsList($data['triggers']);
 		}
 
 		if ($this->data['action'] === 'problem.view') {
-			$actions = makeEventsActions($data['problems'], true);
 			$url_form = clone $url;
 
 			$form = (new CForm('get', 'zabbix.php'))
@@ -726,25 +771,32 @@ class CScreenProblem extends CScreenBase {
 						->getUrl()
 				);
 
-			if ($this->config['event_ack_enable']) {
-				$header_check_box = (new CColHeader(
-					(new CCheckBox('all_eventids'))
-						->onClick("checkAll('".$form->getName()."', 'all_eventids', 'eventids');")
-				))->addClass(ZBX_STYLE_CELL_WIDTH);
-			}
-			else {
-				$header_check_box = null;
-			}
+			$header_check_box = (new CColHeader(
+				(new CCheckBox('all_eventids'))
+					->onClick("checkAll('".$form->getName()."', 'all_eventids', 'eventids');")
+			));
+
+			$this->data['filter']['compact_view']
+				? $header_check_box->addStyle('width: 20px;')
+				: $header_check_box->addClass(ZBX_STYLE_CELL_WIDTH);
 
 			$link = $url
 				->setArgument('page', $this->data['page'])
 				->getUrl();
 
-			$show_timeline = ($this->data['sort'] === 'clock');
+			$show_timeline = ($this->data['sort'] === 'clock' && !$this->data['filter']['compact_view']
+				&& $this->data['filter']['show_timeline']);
 
+			$show_recovery_data = in_array($this->data['filter']['show'], [
+				TRIGGERS_OPTION_RECENT_PROBLEM,
+				TRIGGERS_OPTION_ALL
+			]);
 			$header_clock =
-				make_sorting_header(_('Time'), 'clock', $this->data['sort'], $this->data['sortorder'], $link)
-					->addClass(ZBX_STYLE_CELL_WIDTH);
+				make_sorting_header(_('Time'), 'clock', $this->data['sort'], $this->data['sortorder'], $link);
+
+			$this->data['filter']['compact_view']
+				? $header_clock->addStyle('width: 115px;')
+				: $header_clock->addClass(ZBX_STYLE_CELL_WIDTH);
 
 			if ($show_timeline) {
 				$header = [
@@ -757,27 +809,76 @@ class CScreenProblem extends CScreenBase {
 				$header = [$header_clock];
 			}
 
-			// create table
-			$table = (new CTableInfo())
-				->setHeader(array_merge($header, [
-					$header_check_box,
-					make_sorting_header(_('Severity'), 'priority', $this->data['sort'], $this->data['sortorder'], $link),
-					(new CColHeader(_('Recovery time')))->addClass(ZBX_STYLE_CELL_WIDTH),
-					_('Status'),
-					_('Info'),
-					make_sorting_header(_('Host'), 'host', $this->data['sort'], $this->data['sortorder'], $link),
-					make_sorting_header(_('Problem'), 'problem', $this->data['sort'], $this->data['sortorder'], $link),
-					_('Duration'),
-					$this->config['event_ack_enable'] ? _('Ack') : null,
-					_('Actions'),
-					_('Tags')
-				]));
+			// Create table.
+			if ($this->data['filter']['compact_view']) {
+				if ($this->data['filter']['show_tags'] == PROBLEMS_SHOW_TAGS_NONE) {
+					$tags_header = null;
+				}
+				else {
+					$tags_header = (new CColHeader(_('Tags')));
 
-			if ($this->config['event_ack_enable']) {
-				$url->setArgument('uncheck', '1');
-				$acknowledges = makeEventsAcknowledges($data['problems'], $url->getUrl());
+					switch ($this->data['filter']['show_tags']) {
+						case PROBLEMS_SHOW_TAGS_1:
+							$tags_header->addClass(ZBX_STYLE_COLUMN_TAGS_1);
+							break;
+						case PROBLEMS_SHOW_TAGS_2:
+							$tags_header->addClass(ZBX_STYLE_COLUMN_TAGS_2);
+							break;
+						case PROBLEMS_SHOW_TAGS_3:
+							$tags_header->addClass(ZBX_STYLE_COLUMN_TAGS_3);
+							break;
+					}
+				}
+
+				$table = (new CTableInfo())
+					->setHeader(array_merge($header, [
+						$header_check_box,
+						make_sorting_header(_('Severity'), 'severity', $this->data['sort'], $this->data['sortorder'],
+							$link
+						)->addStyle('width: 120px;'),
+						$show_recovery_data ? (new CColHeader(_('Recovery time')))->addStyle('width: 115px;') : null,
+						$show_recovery_data ? (new CColHeader(_('Status')))->addStyle('width: 70px;') : null,
+						(new CColHeader(_('Info')))->addStyle('width: 24px;'),
+						make_sorting_header(_('Host'), 'host', $this->data['sort'], $this->data['sortorder'], $link)
+							->addStyle('width: 42%;'),
+						make_sorting_header(_('Problem'), 'name', $this->data['sort'], $this->data['sortorder'], $link)
+							->addStyle('width: 58%;'),
+						(new CColHeader(_('Duration')))->addStyle('width: 73px;'),
+						(new CColHeader(_('Ack')))->addStyle('width: 36px;'),
+						(new CColHeader(_('Actions')))->addStyle('width: 64px;'),
+						$tags_header
+					]))
+						->addClass(ZBX_STYLE_COMPACT_VIEW)
+						->addClass(ZBX_STYLE_OVERFLOW_ELLIPSIS);
 			}
-			$tags = makeEventsTags($data['problems']);
+			else {
+				$table = (new CTableInfo())
+					->setHeader(array_merge($header, [
+						$header_check_box,
+						make_sorting_header(_('Severity'), 'severity', $this->data['sort'], $this->data['sortorder'],
+							$link
+						),
+						$show_recovery_data
+							? (new CColHeader(_('Recovery time')))->addClass(ZBX_STYLE_CELL_WIDTH)
+							: null,
+						$show_recovery_data ? _('Status') : null,
+						_('Info'),
+						make_sorting_header(_('Host'), 'host', $this->data['sort'], $this->data['sortorder'], $link),
+						make_sorting_header(_('Problem'), 'name', $this->data['sort'], $this->data['sortorder'], $link),
+						_('Duration'),
+						_('Ack'),
+						_('Actions'),
+						$this->data['filter']['show_tags'] ? _('Tags') : null
+					]));
+			}
+
+			if ($this->data['filter']['show_tags']) {
+				$tags = makeTags($data['problems'], true, 'eventid', $this->data['filter']['show_tags'],
+					array_key_exists('tags', $this->data['filter']) ? $this->data['filter']['tags'] : [],
+					$this->data['filter']['tag_name_format'], $this->data['filter']['tag_priority']
+				);
+			}
+
 			if ($data['problems']) {
 				$triggers_hosts = makeTriggersHostsList($triggers_hosts);
 			}
@@ -785,6 +886,17 @@ class CScreenProblem extends CScreenBase {
 			$last_clock = 0;
 			$today = strtotime('today');
 
+			// Make trigger dependencies.
+			if ($data['triggers']) {
+				$dependencies = getTriggerDependencies($data['triggers']);
+			}
+
+			// Create link to Problem update page.
+			$problem_update_url = (new CUrl('zabbix.php'))
+				->setArgument('action', 'acknowledge.edit')
+				->setArgument('backurl', $url->setArgument('uncheck', '1')->getUrl());
+
+			// Add problems to table.
 			foreach ($data['problems'] as $eventid => $problem) {
 				$trigger = $data['triggers'][$problem['objectid']];
 
@@ -796,6 +908,7 @@ class CScreenProblem extends CScreenBase {
 						->setArgument('triggerid', $problem['objectid'])
 						->setArgument('eventid', $problem['eventid'])
 				));
+
 				if ($problem['r_eventid'] != 0) {
 					$cell_r_clock = ($problem['r_clock'] >= $today)
 						? zbx_date2str(TIME_FORMAT_SECONDS, $problem['r_clock'])
@@ -820,12 +933,10 @@ class CScreenProblem extends CScreenBase {
 				else {
 					$in_closing = false;
 
-					if ($this->config['event_ack_enable']) {
-						foreach ($problem['acknowledges'] as $acknowledge) {
-							if ($acknowledge['action'] == ZBX_ACKNOWLEDGE_ACTION_CLOSE_PROBLEM) {
-								$in_closing = true;
-								break;
-							}
+					foreach ($problem['acknowledges'] as $acknowledge) {
+						if (($acknowledge['action'] & ZBX_PROBLEM_UPDATE_CLOSE) == ZBX_PROBLEM_UPDATE_CLOSE) {
+							$in_closing = true;
+							break;
 						}
 					}
 
@@ -838,7 +949,7 @@ class CScreenProblem extends CScreenBase {
 
 				// Add colors and blinking to span depending on configuration and trigger parameters.
 				addTriggerValueStyle($cell_status, $value, $value_clock,
-					$this->config['event_ack_enable'] ? (bool) $problem['acknowledges'] : false
+					$problem['acknowledged'] == EVENT_ACKNOWLEDGED
 				);
 
 				// Info.
@@ -862,14 +973,31 @@ class CScreenProblem extends CScreenBase {
 					}
 				}
 
-				$description = [
-					(new CSpan(CMacrosResolverHelper::resolveEventDescription(
-						$trigger + ['clock' => $problem['clock'], 'ns' => $problem['ns']]
-					)))
-						->setMenuPopup(CMenuPopupHelper::getTrigger($trigger))
-						->addClass(ZBX_STYLE_LINK_ACTION)
+				if (array_key_exists('suppression_data', $problem) && $problem['suppression_data']) {
+					$info_icons[] = makeSuppressedProblemIcon($problem['suppression_data']);
+				}
+
+				$cell_info = ($this->data['filter']['compact_view'] && $this->data['filter']['show_suppressed']
+						&& count($info_icons) > 1)
+					? (new CSpan(
+							(new CButton(null))
+								->addClass(ZBX_STYLE_ICON_WZRD_ACTION)
+								->addStyle('margin-left: -3px;')
+								->setHint((new CDiv($info_icons))->addClass(ZBX_STYLE_REL_CONTAINER))
+							))->addClass(ZBX_STYLE_REL_CONTAINER)
+					: makeInformationList($info_icons);
+
+				$options = [
+					'description_enabled' => ($trigger['comments'] !== ''
+						|| ($trigger['editable'] && $trigger['flags'] == ZBX_FLAG_DISCOVERY_NORMAL))
 				];
 
+				$description = array_key_exists($trigger['triggerid'], $dependencies)
+					? makeTriggerDependencies($dependencies[$trigger['triggerid']])
+					: [];
+				$description[] = (new CLinkAction($problem['name']))
+					->setMenuPopup(CMenuPopupHelper::getTrigger($trigger, null, $options));
+
 				if ($this->data['filter']['details'] == 1) {
 					$description[] = BR();
 
@@ -904,38 +1032,43 @@ class CScreenProblem extends CScreenBase {
 					];
 				}
 
+				// Create acknowledge link.
+				$problem_update_url->setArgument('eventids', [$problem['eventid']]);
+				$acknowledged = ($problem['acknowledged'] == EVENT_ACKNOWLEDGED);
+				$problem_update_link = (new CLink($acknowledged ? _('Yes') : _('No'), $problem_update_url->getUrl()))
+					->addClass($acknowledged ? ZBX_STYLE_GREEN : ZBX_STYLE_RED)
+					->addClass(ZBX_STYLE_LINK_ALT);
+
+				// Add table row.
 				$table->addRow(array_merge($row, [
-					$this->config['event_ack_enable']
-						? new CCheckBox('eventids['.$problem['eventid'].']', $problem['eventid'])
-						: null,
-					getSeverityCell($trigger['priority'], $this->config, null, $value == TRIGGER_VALUE_FALSE),
-					$cell_r_clock,
-					$cell_status,
-					makeInformationList($info_icons),
+					new CCheckBox('eventids['.$problem['eventid'].']', $problem['eventid']),
+					getSeverityCell($problem['severity'], $this->config, null, $value == TRIGGER_VALUE_FALSE),
+					$show_recovery_data ? $cell_r_clock : null,
+					$show_recovery_data ? $cell_status : null,
+					$cell_info,
 					$triggers_hosts[$trigger['triggerid']],
 					$description,
 					($problem['r_eventid'] != 0)
 						? zbx_date2age($problem['clock'], $problem['r_clock'])
 						: zbx_date2age($problem['clock']),
-					$this->config['event_ack_enable'] ? $acknowledges[$problem['eventid']] : null,
-					array_key_exists($eventid, $actions)
-						? (new CCol($actions[$eventid]))->addClass(ZBX_STYLE_NOWRAP)
-						: '',
-					$tags[$problem['eventid']]
-				]));
+					$problem_update_link,
+					makeEventActionsIcons($problem['eventid'], $data['actions'], $data['mediatypes'], $data['users'],
+						$this->config
+					),
+					$this->data['filter']['show_tags'] ? $tags[$problem['eventid']] : null
+				]), ($this->data['filter']['highlight_row'] && $value == TRIGGER_VALUE_TRUE)
+					? getSeverityFlhStyle($problem['severity'])
+					: null
+				);
 			}
 
-			$footer = null;
-			if ($this->config['event_ack_enable']) {
-				$footer = new CActionButtonList('action', 'eventids', [
-					'acknowledge.edit' => ['name' => _('Bulk acknowledge')]
-				], 'problem');
-			}
+			$footer = new CActionButtonList('action', 'eventids', [
+				'acknowledge.edit' => ['name' => _('Mass update')]
+			], 'problem');
 
 			return $this->getOutput($form->addItem([$table, $paging, $footer]), true, $this->data);
 		}
 		else {
-			$actions = makeEventsActions($data['problems'], true, false);
 			$csv = [];
 
 			$csv[] = [
@@ -946,12 +1079,12 @@ class CScreenProblem extends CScreenBase {
 				_('Host'),
 				_('Problem'),
 				_('Duration'),
-				$this->config['event_ack_enable'] ? _('Ack') : null,
+				_('Ack'),
 				_('Actions'),
 				_('Tags')
 			];
 
-			$tags = makeEventsTags($data['problems'], false);
+			$tags = makeTags($data['problems'], false);
 
 			foreach ($data['problems'] as $problem) {
 				$trigger = $data['triggers'][$problem['objectid']];
@@ -962,12 +1095,10 @@ class CScreenProblem extends CScreenBase {
 				else {
 					$in_closing = false;
 
-					if ($this->config['event_ack_enable']) {
-						foreach ($problem['acknowledges'] as $acknowledge) {
-							if ($acknowledge['action'] == ZBX_ACKNOWLEDGE_ACTION_CLOSE_PROBLEM) {
-								$in_closing = true;
-								break;
-							}
+					foreach ($problem['acknowledges'] as $acknowledge) {
+						if (($acknowledge['action'] & ZBX_PROBLEM_UPDATE_CLOSE) == ZBX_PROBLEM_UPDATE_CLOSE) {
+							$in_closing = true;
+							break;
 						}
 					}
 
@@ -979,22 +1110,33 @@ class CScreenProblem extends CScreenBase {
 					$hosts[] = $trigger_host['name'];
 				}
 
+				$actions_performed = [];
+				if ($data['actions']['messages'][$problem['eventid']]['count'] > 0) {
+					$actions_performed[] =
+							_('Messages').' ('.$data['actions']['messages'][$problem['eventid']]['count'].')';
+				}
+				if ($data['actions']['severities'][$problem['eventid']]['count'] > 0) {
+					$actions_performed[] = _('Severity changes');
+				}
+				if ($data['actions']['actions'][$problem['eventid']]['count'] > 0) {
+					$actions_performed[] =
+							_('Actions').' ('.$data['actions']['actions'][$problem['eventid']]['count'].')';
+				}
+
 				$csv[] = [
-					getSeverityName($trigger['priority'], $this->config),
+					getSeverityName($problem['severity'], $this->config),
 					zbx_date2str(DATE_TIME_FORMAT_SECONDS, $problem['clock']),
 					($problem['r_eventid'] != 0)
 						? zbx_date2str(DATE_TIME_FORMAT_SECONDS, $problem['r_clock'])
 						: '',
 					$value_str,
 					implode(', ', $hosts),
-					CMacrosResolverHelper::resolveEventDescription(
-						$trigger + ['clock' => $problem['clock'], 'ns' => $problem['ns']]
-					),
+					$problem['name'],
 					($problem['r_eventid'] != 0)
 						? zbx_date2age($problem['clock'], $problem['r_clock'])
 						: zbx_date2age($problem['clock']),
-					$this->config['event_ack_enable'] ? ($problem['acknowledges'] ? _('Yes') : _('No')) : null,
-					array_key_exists($problem['eventid'], $actions) ? $actions[$problem['eventid']] : '',
+					($problem['acknowledged'] == EVENT_ACKNOWLEDGED) ? _('Yes') : _('No'),
+					implode(', ', $actions_performed),
 					implode(', ', $tags[$problem['eventid']])
 				];
 			}
