@@ -49,7 +49,9 @@ $widget = (new CWidget())
 	]));
 
 // filter
-$filter = (new CFilter())
+$filter = new CFilter();
+
+$filter
 	->setProfile($data['profileIdx'])
 	->setActiveTab($data['active_tab'])
 	->addFilterTab(_('Filter'), [
@@ -59,6 +61,23 @@ $filter = (new CFilter())
 					->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
 					->setAttribute('autofocus', 'autofocus')
 			)
+			->addRow(
+				(new CLabel(_('Templates'), 'filter_templates__ms')),
+				(new CMultiSelect([
+					'name' => 'filter_templates[]',
+					'object_name' => 'templates',
+					'data' => $data['filter']['templates'],
+					'popup' => [
+						'parameters' => [
+							'srctbl' => 'templates',
+							'srcfld1' => 'hostid',
+							'srcfld2' => 'host',
+							'dstfrm' => $filter->getName(),
+							'dstfld1' => 'filter_templates_'
+						]
+					]
+				]))->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
+			)
 			->addRow(_('Monitored by'),
 				(new CRadioButtonList('filter_monitored_by', (int) $data['filter']['monitored_by']))
 					->addValue(_('Any'), ZBX_MONITORED_BY_ANY)
@@ -72,6 +91,7 @@ $filter = (new CFilter())
 					'name' => 'filter_proxyids[]',
 					'object_name' => 'proxies',
 					'data' => $data['proxies_ms'],
+					'disabled' => ($data['filter']['monitored_by'] != ZBX_MONITORED_BY_PROXY),
 					'popup' => [
 						'parameters' => [
 							'srctbl' => 'proxies',
@@ -81,8 +101,7 @@ $filter = (new CFilter())
 							'dstfld1' => 'filter_proxyids_'
 						]
 					]
-				]))->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH),
-				'filter_proxyids_row'
+				]))->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
 			),
 		(new CFormList())
 			->addRow(_('DNS'),
