@@ -1,6 +1,6 @@
 /*
  ** Zabbix
- ** Copyright (C) 2001-2017 Zabbix SIA
+ ** Copyright (C) 2001-2018 Zabbix SIA
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -20,8 +20,20 @@
 
 jQuery(function($) {
 
-	if ($('#search').length) {
+	var $search = $('#search');
+
+	if ($search.length) {
 		createSuggest('search');
+
+		$search.keyup(function() {
+			$search
+				.siblings('button')
+				.attr('disabled', ($.trim($search.val()) === '') ? true : null);
+		}).closest('form').submit(function() {
+			if ($.trim($search.val()) === '') {
+				return false;
+			}
+		});
 	}
 
 	if (IE) {
@@ -52,21 +64,30 @@ jQuery(function($) {
 	/**
 	 * Build menu popup for given elements.
 	 */
-	$(document).on('click', '[data-menu-popup]', function(event) {
+	$(document).on('keydown click', '[data-menu-popup]', function(event) {
 		var obj = $(this),
 			data = obj.data('menu-popup');
 
+		if (event.type === 'keydown') {
+			if (event.which != 13) {
+				return;
+			}
+
+			event.preventDefault();
+			event.target = this;
+		}
+
 		switch (data.type) {
 			case 'history':
 				data = getMenuPopupHistory(data);
 				break;
 
 			case 'host':
-				data = getMenuPopupHost(data);
+				data = getMenuPopupHost(data, obj);
 				break;
 
 			case 'map':
-				data = getMenuPopupMap(data);
+				data = getMenuPopupMap(data, obj);
 				break;
 
 			case 'refresh':
@@ -78,7 +99,7 @@ jQuery(function($) {
 				break;
 
 			case 'triggerLog':
-				data = getMenuPopupTriggerLog(data);
+				data = getMenuPopupTriggerLog(data, obj);
 				break;
 
 			case 'triggerMacro':
@@ -90,7 +111,7 @@ jQuery(function($) {
 				break;
 
 			case 'dashboard':
-				data = getMenuPopupDashboard(data);
+				data = getMenuPopupDashboard(data, obj);
 				break;
 		}
 
@@ -108,40 +129,52 @@ jQuery(function($) {
 	 * @param object data
 	 * @param string data.object   object name
 	 * @param array  data.values   values
-	 * @param array  data.elements values for multiple input elements
 	 * @param string data.parentId parent id
 	 */
 	$(document).on('add.popup', function(e, data) {
-		if (data.elements) {
-			jQuery.each(data.elements, function(_, element) {
-				jQuery('#' + element.id).val(element.value);
-			});
-		}
-		else if (data.values) {
-			// multiselect check
-			if ($('#' + data.parentId).hasClass('multiselect')) {
-				for (var i = 0; i < data.values.length; i++) {
-					if (typeof data.values[i].id !== 'undefined') {
-						var item = {
-							'id': data.values[i].id,
-							'name': data.values[i].name
-						};
+		// multiselect check
+		if ($('#' + data.parentId).hasClass('multiselect')) {
+			for (var i = 0; i < data.values.length; i++) {
+				if (typeof data.values[i].id !== 'undefined') {
+					var item = {
+						'id': data.values[i].id,
+						'name': data.values[i].name
+					};
 
-						if (typeof data.values[i].prefix !== 'undefined') {
-							item.prefix = data.values[i].prefix;
-						}
-
-						jQuery('#' + data.parentId).multiSelect('addData', item);
+					if (typeof data.values[i].prefix !== 'undefined') {
+						item.prefix = data.values[i].prefix;
 					}
+
+					$('#' + data.parentId).multiSelect('addData', item);
 				}
 			}
-			else if (typeof addPopupValues !== 'undefined') {
-				// execute function if they exist
-				addPopupValues(data);
-			}
-			else {
-				jQuery('#' + data.parentId).val(data.values[0].name);
-			}
+		}
+		else if ($('[name="'+data.parentId+'"]').hasClass('patternselect')) {
+			/**
+			 * Pattern select allows enter multiple comma or newline separated values in same editable field. Values
+			 * passed to add.popup should be appended at the and of existing value string. Duplicates are skipped.
+			 */
+			var values = $('[name="'+data.parentId+'"]').val();
+			data.values.forEach(function(val) {
+				var escaped = val[data.object].replace(/[.*+?^${}()|[\]\\]/g, '\\$&');
+				if (!values.match(new RegExp('(' + escaped + '([,|\n]|$))', 'gm'))) {
+					if (values !== '') {
+						values = values + ', ';
+					}
+					values = values + val[data.object];
+				}
+			});
+
+			$('[name="'+data.parentId+'"]')
+				.val(values)
+				.trigger('change');
+		}
+		else if (typeof addPopupValues !== 'undefined') {
+			// execute function if they exist
+			addPopupValues(data);
+		}
+		else {
+			$('#' + data.parentId).val(data.values[0].name);
 		}
 	});
 
@@ -153,5 +186,8 @@ jQuery(function($) {
 		if (typeof confirmation === 'undefined' || (typeof confirmation !== 'undefined' && confirm(confirmation))) {
 			window.location = button.data('url');
 		}
-	})
+	});
+
+	// Initialize hintBox event handlers.
+	hintBox.bindEvents();
 });
