@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2017 Zabbix SIA
+** Copyright (C) 2001-2018 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -19,6 +19,17 @@
 
 
 jQuery(function($) {
+	var KEY = {
+		ARROW_DOWN: 40,
+		ARROW_LEFT: 37,
+		ARROW_RIGHT: 39,
+		ARROW_UP: 38,
+		BACKSPACE: 8,
+		DELETE: 46,
+		ENTER: 13,
+		ESCAPE: 27,
+		TAB: 9
+	};
 
 	/**
 	 * Multi select helper.
@@ -76,7 +87,7 @@ jQuery(function($) {
 				data[data.length] = {
 					id: id,
 					name: item.name,
-					prefix: (item.prefix === 'undefined') ? '' : item.prefix
+					prefix: (typeof item.prefix === 'undefined') ? '' : item.prefix
 				};
 			}
 
@@ -84,7 +95,7 @@ jQuery(function($) {
 		},
 
 		/**
-		 * Rezise multiselect selected text
+		 * Resize multiselect selected text
 		 *
 		 * @return jQuery
 		 */
@@ -137,6 +148,58 @@ jQuery(function($) {
 
 				cleanAvailable(obj, ms.values);
 			});
+		},
+
+		/**
+		 * Disable multi select UI control.
+		 *
+		 * @return jQuery
+		 */
+		disable: function() {
+			return this.each(function() {
+				var $obj = $(this),
+					$wrapper = $obj.parent('.multiselect-wrapper'),
+					ms = $obj.data('multiSelect');
+
+				if (ms.options.disabled === false) {
+					$('.multiselect-list', $obj).addClass('disabled');
+					$('.multiselect-button > button', $wrapper).attr('disabled', 'disabled');
+					$('input[type=text]', $wrapper).remove();
+					cleanAvailable($obj, ms.values);
+					$('.available', $wrapper).remove();
+
+					ms.options.disabled = true;
+				}
+			});
+		},
+
+		/**
+		 * Enable multi select UI control.
+		 *
+		 * @return jQuery
+		 */
+		enable: function() {
+			return this.each(function() {
+				var $obj = $(this),
+					$wrapper = $obj.parent('.multiselect-wrapper'),
+					ms = $(this).data('multiSelect');
+
+				if (ms.options.disabled === true) {
+					var $input = makeMultiSelectInput($obj);
+					$('.multiselect-list', $obj).removeClass('disabled');
+					$('.multiselect-button > button', $wrapper).removeAttr('disabled');
+					$obj.append($input);
+					makeSuggsetionsBlock($obj);
+
+					// set readonly
+					if (ms.options.selectedLimit != 0 && $('.selected li', $obj).length >= ms.options.selectedLimit) {
+						setSearchFieldVisibility(false, $obj, ms.options);
+					}
+
+					ms.values.isAvailableOpened = true;
+					ms.options.disabled = false;
+				}
+			});
 		}
 	};
 
@@ -150,7 +213,9 @@ jQuery(function($) {
 	 * @param string options['data'][id]
 	 * @param string options['data'][name]
 	 * @param string options['data'][prefix]		(optional)
-	 * @param array  options['ignored']				preload ignored {id: name} (optional)
+	 * @param bool   options['data'][inaccessible]	(optional)
+	 * @param bool   options['data'][disabled]		(optional)
+	 * @param array  options['excludeids']			the list of excluded ids (optional)
 	 * @param string options['defaultValue']		default value for input element (optional)
 	 * @param bool   options['disabled']			turn on/off readonly state (optional)
 	 * @param bool   options['addNew']				allow user to create new names (optional)
@@ -183,7 +248,8 @@ jQuery(function($) {
 				'Select': 'Select'
 			},
 			data: [],
-			ignored: {},
+			only_hostid: 0,
+			excludeids: [],
 			addNew: false,
 			defaultValue: null,
 			disabled: false,
@@ -194,21 +260,13 @@ jQuery(function($) {
 		};
 		options = $.extend({}, defaults, options);
 
-		var KEY = {
-			ARROW_DOWN: 40,
-			ARROW_LEFT: 37,
-			ARROW_RIGHT: 39,
-			ARROW_UP: 38,
-			BACKSPACE: 8,
-			DELETE: 46,
-			ENTER: 13,
-			ESCAPE: 27,
-			TAB: 9
-		};
-
 		return this.each(function() {
 			var obj = $(this);
 
+			options = $.extend({}, {
+				required: (typeof obj.attr('aria-required') !== 'undefined') ? obj.attr('aria-required') : false
+			}, options);
+
 			var ms = {
 				options: options,
 				values: {
@@ -219,11 +277,12 @@ jQuery(function($) {
 					isMoreMatchesFound: false,
 					isAvailableOpened: false,
 					selected: {},
-					available: {},
-					ignored: empty(options.ignored) ? {} : options.ignored
+					available: {}
 				}
 			};
 
+			obj.removeAttr('aria-required');
+
 			// store the configuration in the elements data
 			obj.data('multiSelect', ms);
 
@@ -242,281 +301,19 @@ jQuery(function($) {
 			var selected_ul = $('<ul>', {
 				'class': 'multiselect-list'
 			});
+
+			obj.append(selected_div.append(selected_ul));
+
 			if (options.disabled) {
 				selected_ul.addClass('disabled');
 			}
-			obj.append(selected_div.append(selected_ul));
-
-			// search input
-			if (!options.disabled) {
-				var input = $('<input>', {
-					'class': 'input',
-					type: 'text'
-				})
-				.attr('placeholder', options.labels['type here to search'])
-				.on('keyup change', function(e) {
-					if (typeof(e.which) === 'undefined') {
-						return false;
-					}
-
-					switch (e.which) {
-						case KEY.ARROW_DOWN:
-						case KEY.ARROW_LEFT:
-						case KEY.ARROW_RIGHT:
-						case KEY.ARROW_UP:
-							return false;
-						case KEY.ESCAPE:
-							cleanSearchInput(obj);
-							return false;
-					}
-
-					if (options.selectedLimit != 0 && $('.selected li', obj).length >= options.selectedLimit) {
-						setReadonly(obj);
-						return false;
-					}
-
-					var search = input.val();
-
-					// Replace trailing slashes to check if search term contains anything else.
-					if (!empty(search)) {
-						if (input.data('lastSearch') != search) {
-							if (!values.isWaiting) {
-								values.isWaiting = true;
-
-								var jqxhr = null;
-								window.setTimeout(function() {
-									values.isWaiting = false;
-
-									var search = input.val();
-
-									// re-check search after delay
-									if (!empty(search) && input.data('lastSearch') != search) {
-										values.search = search;
-
-										input.data('lastSearch', values.search);
-
-										if (!empty(jqxhr)) {
-											jqxhr.abort();
-										}
-
-										values.isAjaxLoaded = false;
-
-										jqxhr = $.ajax({
-											url: options.url + '&curtime=' + new CDate().getTime(),
-											type: 'GET',
-											dataType: 'json',
-											cache: false,
-											data: {
-												search: values.search,
-												limit: getLimit(values, options)
-											},
-											success: function(data) {
-												values.isAjaxLoaded = true;
-
-												loadAvailable(data.result, obj, values, options);
-											}
-										});
-									}
-								}, 500);
-							}
-						}
-						else {
-							if ($('.available', obj).is(':hidden')) {
-								showAvailable(obj, values);
-							}
-						}
-					}
-					else {
-						hideAvailable(obj);
-					}
-				})
-				.on('keypress keydown', function(e) {
-					switch (e.which) {
-						case KEY.ENTER:
-							if (!empty(input.val())) {
-								var selected = $('.available li.suggest-hover', obj);
-
-								if (selected.length > 0) {
-									select(selected.data('id'), obj, values, options);
-								}
-
-								// stop form submit
-								cancelEvent(e);
-
-								return false;
-							}
-							break;
-
-						case KEY.BACKSPACE:
-							if (empty(input.val())) {
-								var selected = $('.selected li.selected', obj);
-
-								if (selected.length > 0) {
-									var prev = selected.prev();
-
-									removeSelected(selected.data('id'), obj, values, options);
-
-									if (prev.length > 0) {
-										prev.addClass('selected');
-									}
-									else {
-										$('.selected li:first-child', obj).addClass('selected');
-									}
-								}
-								else if ($('.selected li', obj).length > 0) {
-									$('.selected li:last-child', obj).addClass('selected');
-								}
-
-								cancelEvent(e);
-
-								return false;
-							}
-							break;
-
-						case KEY.DELETE:
-							if (empty(input.val())) {
-								var selected = $('.selected li.selected', obj);
-
-								if (selected.length > 0) {
-									var next = selected.next();
-
-									removeSelected(selected.data('id'), obj, values, options);
-
-									if (next.length > 0) {
-										next.addClass('selected');
-									}
-									else {
-										$('.selected li:last-child', obj).addClass('selected');
-									}
-								}
-
-								cancelEvent(e);
-
-								return false;
-							}
-							break;
-
-						case KEY.ARROW_LEFT:
-							if (empty(input.val())) {
-								if ($('.selected li.selected', obj).length > 0) {
-									var prev = $('.selected li.selected', obj).removeClass('selected').prev();
-
-									if (prev.length > 0) {
-										prev.addClass('selected');
-									}
-									else {
-										$('.selected li:first-child', obj).addClass('selected');
-									}
-								}
-								else if ($('.selected li', obj).length > 0) {
-									$('.selected li:last-child', obj).addClass('selected');
-								}
-							}
-							break;
-
-						case KEY.ARROW_RIGHT:
-							if ($('.selected li.selected', obj).length > 0) {
-								var next = $('.selected li.selected', obj).removeClass('selected').next();
-
-								if (next.length > 0) {
-									next.addClass('selected');
-								}
-							}
-							break;
-
-						case KEY.ARROW_UP:
-							if ($('.available', obj).is(':visible') && $('.available li', obj).length > 0) {
-								var selected = $('.available li.suggest-hover', obj);
-									prev = null;
-
-								if (selected.length === 0) {
-									// Select last element.
-									prev = $('ul.multiselect-suggest li:last-child', obj);
-								}
-								else {
-									selected.removeClass('suggest-hover');
-									prev = selected.prev();
-								}
-
-								if (prev.length === 0) {
-									// Select search input.
-									$('input[type="text"]', obj).val(values.search);
-								}
-								else {
-									prev.addClass('suggest-hover');
-									$('input[type="text"]', obj).val(values.available[prev.data('id')]['name']);
-								}
-
-								// Position cursor at the end of search input.
-								cancelEvent(e);
-
-								scrollAvailable(obj);
-							}
-							break;
-
-						case KEY.ARROW_DOWN:
-							if ($('.available', obj).is(':visible') && $('.available li', obj).length > 0) {
-								var selected = $('.available li.suggest-hover', obj),
-									next;
-
-								if (selected.length === 0) {
-									// Select first element.
-									next = $('ul.multiselect-suggest li:first-child', obj);
-								}
-								else {
-									selected.removeClass('suggest-hover');
-
-									next = selected.next();
-								}
-
-								if (next.length === 0) {
-									// Select search input.
-									$('input[type="text"]', obj).val(values.search);
-								}
-								else {
-									next.addClass('suggest-hover');
-									$('input[type="text"]', obj).val(values.available[next.data('id')]['name']);
-								}
-
-								scrollAvailable(obj);
-							}
-							break;
-
-						case KEY.TAB:
-						case KEY.ESCAPE:
-							hideAvailable(obj);
-							cleanSearchInput(obj);
-							break;
-					}
-				})
-				.focusin(function() {
-					if (options.selectedLimit == 0 || $('.selected li', obj).length < options.selectedLimit) {
-						$(obj).addClass('active');
-					}
-				})
-				.focusout(function() {
-					$(obj).removeClass('active');
-					cleanSearchInput(obj);
-				});
-				obj.append(input);
+			else {
+				obj.append(makeMultiSelectInput(obj));
 			}
 
 			// available
 			if (!options.disabled) {
-				var available = $('<div>', {
-					'class': 'available',
-					css: { display: 'none' }
-				});
-
-				// multi select
-				obj.append(available)
-				.focusout(function() {
-					setTimeout(function() {
-						if (!values.isAvailableOpened && $('.available', obj).is(':visible')) {
-							hideAvailable(obj);
-						}
-					}, 200);
-				});
+				makeSuggsetionsBlock(obj);
 			}
 
 			// preload data
@@ -531,12 +328,10 @@ jQuery(function($) {
 
 			// draw popup link
 			if (options.popup.parameters != null) {
-				var urlParameters = options.popup.parameters;
+				var popup_options = options.popup.parameters;
 
-				if (options.ignored) {
-					$.each(options.ignored, function(i, value) {
-						urlParameters = urlParameters + '&excludeids[]=' + i;
-					});
+				if (typeof popup_options['only_hostid'] !== 'undefined') {
+					options.only_hostid = popup_options['only_hostid'];
 				}
 
 				var popupButton = $('<button>', {
@@ -548,23 +343,267 @@ jQuery(function($) {
 				if (options.disabled) {
 					popupButton.attr('disabled', true);
 				}
-				else {
-					popupButton.click(function() {
-						return PopUp('popup.php?' + urlParameters, options.popup.width, options.popup.height);
-					});
-				}
+
+				popupButton.click(function(event) {
+					return PopUp('popup.generic', popup_options, null, event.target);
+				});
 
 				obj.parent().append($('<div>', {
 					'class': 'multiselect-button'
 				}).append(popupButton));
 			}
-
-			if ('postInitEvent' in options) {
-				jQuery(document).trigger(options.postInitEvent);
-			}
 		});
 	};
 
+	function makeSuggsetionsBlock($obj) {
+		var ms = $obj.data('multiSelect'),
+			values = ms.values,
+			$available = $('<div>', {
+				'class': 'available',
+				css: { display: 'none' }
+			});
+
+		// multi select
+		$obj.append($available)
+			.focusout(function() {
+				setTimeout(function() {
+					if (!values.isAvailableOpened && $('.available', $obj).is(':visible')) {
+						hideAvailable($obj);
+					}
+				}, 200);
+			});
+	}
+
+	function makeMultiSelectInput($obj) {
+		var ms = $obj.data('multiSelect'),
+			values = ms.values,
+			options = ms.options,
+			$label = $('label[for=' + $obj.attr('id') + '_ms]'),
+			$aria_live = $('[aria-live]', $obj),
+			$input = $('<input>', {
+				'id': $label.length ? $label.attr('for') : null,
+				'class': 'input',
+				'type': 'text',
+				'placeholder': options.labels['type here to search'],
+				'aria-label': ($label.length ? $label.text() + '. ' : '') + options.labels['type here to search'],
+				'aria-required': options.required
+			})
+			.on('keyup change', function(e) {
+
+				if (typeof e.which === 'undefined') {
+					return false;
+				}
+
+				switch (e.which) {
+					case KEY.ARROW_DOWN:
+					case KEY.ARROW_LEFT:
+					case KEY.ARROW_RIGHT:
+					case KEY.ARROW_UP:
+						return false;
+					case KEY.ESCAPE:
+						cleanSearchInput($obj);
+						return false;
+				}
+
+				if (options.selectedLimit != 0 && $('.selected li', $obj).length >= options.selectedLimit) {
+					setSearchFieldVisibility(false, $obj, options);
+					return false;
+				}
+
+				var search = $input.val();
+
+				// Replace trailing slashes to check if search term contains anything else.
+				if (search !== '') {
+					$('.selected li.selected', $obj).removeClass('selected');
+
+					if ($input.data('lastSearch') != search) {
+						if (!values.isWaiting) {
+							values.isWaiting = true;
+
+							var jqxhr = null;
+							window.setTimeout(function() {
+								values.isWaiting = false;
+
+								var search = $input.val();
+
+								// re-check search after delay
+								if (search !== '' && $input.data('lastSearch') != search) {
+									values.search = search;
+
+									$input.data('lastSearch', values.search);
+
+									if (jqxhr != null) {
+										jqxhr.abort();
+									}
+
+									values.isAjaxLoaded = false;
+									var request_data = {
+										search: values.search,
+										limit: getLimit(values, options)
+									}
+
+									jqxhr = $.ajax({
+										url: options.url + '&curtime=' + new CDate().getTime(),
+										type: 'GET',
+										dataType: 'json',
+										cache: false,
+										data: request_data,
+										success: function(data) {
+											values.isAjaxLoaded = true;
+											loadAvailable(data.result, $obj, values, options);
+										}
+									});
+								}
+							}, 500);
+						}
+					}
+					else {
+						if ($('.available', $obj).is(':hidden')) {
+							showAvailable($obj, values);
+						}
+					}
+				}
+				else {
+					hideAvailable($obj);
+				}
+			})
+			.on('keypress keydown', function(e) {
+				switch (e.which) {
+
+					case KEY.TAB:
+					case KEY.ESCAPE:
+						hideAvailable($obj);
+						cleanSearchInput($obj);
+						break;
+
+					case KEY.ENTER:
+						if ($input.val() !== '') {
+							var $selected = $('.available li.suggest-hover', $obj);
+
+							if ($selected.length) {
+								select($selected.data('id'), $obj, values, options);
+								$aria_live.text(sprintf(t('Added, %1$s'), $selected.data('label')));
+							}
+
+							return cancelEvent(e);
+						}
+						break;
+
+					case KEY.ARROW_LEFT:
+						if ($input.val() === '') {
+							var $collection = $('.selected li', $obj);
+
+							if ($collection.length) {
+								var $prev = $collection.filter('.selected').removeClass('selected').prev();
+								$prev = ($prev.length ? $prev : $collection.last()).addClass('selected');
+
+								$aria_live.text(($prev.hasClass('disabled'))
+									? sprintf(t('%1$s, read only'), $prev.data('label'))
+									: $prev.data('label')
+								);
+							}
+						}
+						break;
+
+					case KEY.ARROW_RIGHT:
+						if ($input.val() === '') {
+							var $collection = $('.selected li', $obj);
+
+							if ($collection.length) {
+								var $next = $collection.filter('.selected').removeClass('selected').next();
+								$next = ($next.length ? $next : $collection.first()).addClass('selected');
+
+								$aria_live.text(($next.hasClass('disabled'))
+									? sprintf(t('%1$s, read only'), $next.data('label'))
+									: $next.data('label')
+								);
+							}
+						}
+						break;
+
+					case KEY.ARROW_UP:
+					case KEY.ARROW_DOWN:
+						var $collection = $('.available:visible li', $obj),
+							$selected = $collection.filter('.suggest-hover').removeClass('suggest-hover');
+
+						if ($selected.length) {
+							$selected = (e.which == KEY.ARROW_UP)
+								? ($selected.is(':first-child') ? $collection.last() : $selected.prev())
+								: ($selected.is(':last-child') ? $collection.first() : $selected.next());
+
+							$selected.addClass('suggest-hover');
+							$aria_live.text($selected.data('label'));
+						}
+
+						scrollAvailable($obj);
+						return cancelEvent(e);
+
+					case KEY.BACKSPACE:
+					case KEY.DELETE:
+						if ($input.val() === '') {
+							var $selected = $('.selected li.selected', $obj);
+
+							if ($selected.length) {
+								var id = $selected.data('id'),
+									item = values.selected[id];
+
+								if (typeof item.disabled === 'undefined' || !item.disabled) {
+									var aria_text = sprintf(t('Removed, %1$s'), $selected.data('label'));
+
+									$selected = (e.which == KEY.BACKSPACE)
+										? ($selected.is(':first-child') ? $selected.next() : $selected.prev())
+										: ($selected.is(':last-child') ? $selected.prev() : $selected.next());
+
+									removeSelected(id, $obj, values, options);
+
+									if ($selected.length) {
+										var $collection = $('.selected li', $obj);
+										$selected.addClass('selected');
+
+										aria_text += ', ' + sprintf(
+											($selected.hasClass('disabled'))
+												? t('Selected, %1$s, read only, in position %2$d of %3$d')
+												: t('Selected, %1$s in position %2$d of %3$d'),
+											$selected.data('label'),
+											$collection.index($selected) + 1,
+											$collection.length
+										);
+									}
+
+									$aria_live.text(aria_text);
+								}
+								else {
+									$aria_live.text(t('Can not be removed'));
+								}
+							}
+							else if (e.which == KEY.BACKSPACE) {
+								/* Pressing Backspace on empty input field should select last element in
+								 * multiselect. For next Backspace press to be able to remove it.
+								 */
+								var $selected = $('.selected li:last-child', $obj).addClass('selected');
+								$aria_live.text($selected.data('label'));
+							}
+
+							return cancelEvent(e);
+						}
+						break;
+				}
+			})
+			.on('focusin', function() {
+				$obj.addClass('active');
+
+				if (getSearchFieldVisibility($obj) == false) {
+					$('.selected li:first-child', $obj).addClass('selected');
+				}
+			})
+			.on('focusout', function() {
+				$obj.removeClass('active').find('li.selected').removeClass('selected');
+				cleanSearchInput($obj);
+			});
+
+		return $input;
+	}
+
 	function setDefaultValue(obj, options) {
 		if (!empty(options.defaultValue)) {
 			obj.append($('<input>', {
@@ -650,7 +689,7 @@ jQuery(function($) {
 				if (options.limit != 0 && objectLength(values.available) < options.limit) {
 					if (typeof values.available[item.id] === 'undefined'
 							&& typeof values.selected[item.id] === 'undefined'
-							&& typeof values.ignored[item.id] === 'undefined') {
+							&& options.excludeids.indexOf(item.id) === -1) {
 						values.available[item.id] = item;
 					}
 				}
@@ -660,6 +699,9 @@ jQuery(function($) {
 			});
 		}
 
+		var found = 0,
+			preselected = '';
+
 		// write empty result label
 		if (objectLength(values.available) == 0) {
 			var div = $('<div>', {
@@ -675,7 +717,8 @@ jQuery(function($) {
 		else {
 			$('.available', obj)
 				.append($('<ul>', {
-					'class': 'multiselect-suggest'
+					'class': 'multiselect-suggest',
+					'aria-hidden': true
 				}))
 				.mouseenter(function() {
 					values.isAvailableOpened = true;
@@ -684,11 +727,29 @@ jQuery(function($) {
 					values.isAvailableOpened = false;
 				});
 
-			$.each(values.available, function(i, item) {
-				addAvailable(item, obj, values, options);
+			$.each(data, function (i, item) {
+				if (typeof values.available[item.id] !== 'undefined') {
+					if (found == 0) {
+						preselected = (item.prefix || '') + item.name;
+					}
+					addAvailable(item, obj, values, options);
+					found++;
+				}
 			});
 		}
 
+		if (found > 0) {
+			$('[aria-live]', obj).text(
+				(values.isMoreMatchesFound
+					? sprintf(t('More than %1$d matches for %2$s found'), found, values.search)
+					: sprintf(t('%1$d matches for %2$s found'), found, values.search)) +
+				', ' + sprintf(t('%1$s preselected, use down,up arrow keys and enter to select'), preselected)
+			);
+		}
+		else {
+			$('[aria-live]', obj).text(options.labels['No matches found']);
+		}
+
 		// write more matches found label
 		if (values.isMoreMatchesFound) {
 			var div = $('<div>', {
@@ -710,7 +771,8 @@ jQuery(function($) {
 			removeDefaultValue(obj, options);
 			values.selected[item.id] = item;
 
-			var prefix = (typeof item.prefix === 'undefined') ? '' : item.prefix;
+			var prefix = (item.prefix || ''),
+				item_disabled = (typeof(item.disabled) !== 'undefined' && item.disabled);
 
 			// add hidden input
 			obj.append($('<input>', {
@@ -721,39 +783,41 @@ jQuery(function($) {
 				'data-prefix': prefix
 			}));
 
-			var close_btn = $('<span>', {
-				'class': 'subfilter-disable-btn'
-			});
-
-			if (!options.disabled) {
-				close_btn.click(function() {
-					removeSelected(item.id, obj, values, options);
-				});
-			}
-
 			var li = $('<li>', {
-				'data-id': item.id
+				'data-id': item.id,
+				'data-label': prefix + item.name
 			}).append(
 				$('<span>', {
 					'class': 'subfilter-enabled'
 				})
 					.append($('<span>', {
-						text: prefix + item.name
+						text: prefix + item.name,
+						title: item.name
 					}))
-					.append(close_btn)
+					.append($('<span>')
+						.addClass('subfilter-disable-btn')
+						.on('click', function() {
+							if (!options.disabled && !item_disabled) {
+								removeSelected(item.id, obj, values, options);
+							}
+						}))
 			);
 
 			if (typeof(item.inaccessible) !== 'undefined' && item.inaccessible) {
 				li.addClass('inaccessible');
 			}
 
+			if (item_disabled) {
+				li.addClass('disabled');
+			}
+
 			$('.selected ul', obj).append(li);
 
 			resizeSelectedText(li, obj);
 
 			// set readonly
 			if (options.selectedLimit != 0 && $('.selected li', obj).length >= options.selectedLimit) {
-				setReadonly(obj);
+				setSearchFieldVisibility(false, obj, options);
 			}
 		}
 	}
@@ -775,13 +839,15 @@ jQuery(function($) {
 		cleanLastSearch(obj);
 
 		if (options.selectedLimit == 0 || $('.selected li', obj).length < options.selectedLimit) {
-			$('input[type="text"]', obj).css({'display': ''}).focus();
+			setSearchFieldVisibility(true, obj, options);
+			$('input[type="text"]', obj).focus();
 		}
 	}
 
 	function addAvailable(item, obj, values, options) {
 		var li = $('<li>', {
-			'data-id': item.id
+			'data-id': item.id,
+			'data-label': (item.prefix || '') + item.name
 		})
 		.click(function() {
 			select(item.id, obj, values, options);
@@ -962,35 +1028,37 @@ jQuery(function($) {
 		}
 	}
 
-	function setReadonly(obj) {
-		$('input[type="text"]', obj).css({'display': 'none'});
-		$(obj).removeClass('active');
+	function setSearchFieldVisibility(visible, container, options) {
+		if (visible) {
+			container.removeClass('search-disabled')
+				.find('input[type="text"]')
+				.attr({
+					placeholder: options.labels['type here to search'],
+					'aria-label': options.labels['type here to search'],
+					readonly: false
+				});
+		}
+		else {
+			container.addClass('search-disabled')
+				.find('input[type="text"]')
+				.attr({
+					placeholder: '',
+					'aria-label': '',
+					readonly: true
+				});
+		}
+	}
+
+	function getSearchFieldVisibility(container) {
+		return container.not('.search-disabled').length > 0;
 	}
 
 	function getLimit(values, options) {
 		return (options.limit != 0)
-			? options.limit + countMatches(values.selected, values.search) + countMatches(values.ignored, values.search) + 1
+			? options.limit + objectLength(values.selected) + options.excludeids.length + 1
 			: null;
 	}
 
-	function countMatches(data, search) {
-		var count = 0;
-
-		if (empty(data)) {
-			return count;
-		}
-
-		for (var id in data) {
-			var name = (typeof(data[id]) == 'object') ? data[id].name : data[id];
-
-			if (name.substr(0, search.length).toUpperCase() == search.toUpperCase()) {
-				count++;
-			}
-		}
-
-		return count;
-	}
-
 	function objectLength(obj) {
 		var length = 0;
 
